@@ -9,9 +9,9 @@ use std::{
 };
 
 use crate::msgs::{
+    AnyRequestId, ObjectId,
     request::InvalidRequestError,
     response::{ResponseKind, RpcError, ValidatedResponse},
-    AnyRequestId, ObjectId,
 };
 
 mod auth;
@@ -22,9 +22,9 @@ mod stream;
 use crate::util::Utf8CString;
 pub use builder::{BuilderError, ConnPtDescription, RpcConnBuilder};
 pub use connimpl::RpcConn;
-use serde::{de::DeserializeOwned, Deserialize};
+use serde::{Deserialize, de::DeserializeOwned};
 pub use stream::StreamError;
-use tor_rpc_connect::{auth::cookie::CookieAccessError, HasClientErrorAction};
+use tor_rpc_connect::{HasClientErrorAction, auth::cookie::CookieAccessError};
 
 /// A handle to an open request.
 ///
@@ -581,8 +581,8 @@ pub enum ConnectError {
 
 impl HasClientErrorAction for ConnectError {
     fn client_action(&self) -> tor_rpc_connect::ClientErrorAction {
-        use tor_rpc_connect::ClientErrorAction as A;
         use ConnectError as E;
+        use tor_rpc_connect::ClientErrorAction as A;
         match self {
             E::BadEnvironment => A::Abort,
             E::CannotParse(e) => e.client_action(),
@@ -607,8 +607,8 @@ impl HasClientErrorAction for ConnectError {
 
 impl HasClientErrorAction for ProtoError {
     fn client_action(&self) -> tor_rpc_connect::ClientErrorAction {
-        use tor_rpc_connect::ClientErrorAction as A;
         use ProtoError as E;
+        use tor_rpc_connect::ClientErrorAction as A;
         match self {
             E::Shutdown(_) => A::Decline,
             E::InternalRequestFailed(_) => A::Decline,
@@ -671,7 +671,7 @@ mod test {
     #![allow(clippy::print_stdout)]
     #![allow(clippy::single_char_pattern)]
     #![allow(clippy::unwrap_used)]
-    #![allow(clippy::unchecked_duration_subtraction)]
+    #![allow(clippy::unchecked_time_subtraction)]
     #![allow(clippy::useless_vec)]
     #![allow(clippy::needless_pass_by_value)]
     //! <!-- @@ end test lint list maintained by maint/add_warning @@ -->
@@ -679,8 +679,8 @@ mod test {
     use std::{sync::atomic::AtomicUsize, thread, time::Duration};
 
     use io::{BufRead as _, BufReader, Write as _};
-    use rand::{seq::SliceRandom as _, Rng as _, SeedableRng as _};
-    use tor_basic_utils::{test_rng::testing_rng, RngExt as _};
+    use rand::{Rng as _, SeedableRng as _, seq::SliceRandom as _};
+    use tor_basic_utils::{RngExt as _, test_rng::testing_rng};
 
     use crate::{
         llconn,
@@ -754,7 +754,7 @@ mod test {
         for th_idx in 0..n_threads {
             let conn = Arc::clone(&conn);
             let n_completed = Arc::clone(&n_completed);
-            let mut rng = rand_chacha::ChaCha12Rng::from_seed(rng.gen());
+            let mut rng = rand_chacha::ChaCha12Rng::from_seed(rng.random());
             let th = thread::spawn(move || {
                 for cmd_idx in 0..n_commands_per_thread {
                     // We are spawning a bunch of worker threads, each of which will run a number of
@@ -762,8 +762,8 @@ mod test {
                     // updates, and an error or a success.
                     // We will double-check that each request gets the response it asked for.
                     let s = format!("{}:{}", th_idx, cmd_idx);
-                    let want_updates: bool = rng.gen();
-                    let want_failure: bool = rng.gen();
+                    let want_updates: bool = rng.random();
+                    let want_failure: bool = rng.random();
                     let req = serde_json::json!({
                         "obj":"fred",
                         "method":"arti:x-echo",
@@ -801,7 +801,7 @@ mod test {
                         assert_eq!(map.get("echo"), Some(&serde_json::Value::String(s)));
                     }
                     n_completed.fetch_add(1, SeqCst);
-                    if rng.gen::<f32>() < 0.02 {
+                    if rng.random::<f32>() < 0.02 {
                         thread::sleep(Duration::from_millis(3));
                     }
                 }
@@ -817,7 +817,7 @@ mod test {
 
         // -----
         // Worker thread: handles user requests.
-        let worker_rng = rand_chacha::ChaCha12Rng::from_seed(rng.gen());
+        let worker_rng = rand_chacha::ChaCha12Rng::from_seed(rng.random());
         let worker_thread = thread::spawn(move || {
             let mut rng = worker_rng;
             let mut sock = BufReader::new(sock);
