@@ -30,7 +30,7 @@
 #![deny(clippy::ref_option_ref)]
 #![warn(clippy::semicolon_if_nothing_returned)]
 #![warn(clippy::trait_duplication_in_bounds)]
-#![deny(clippy::unchecked_duration_subtraction)]
+#![deny(clippy::unchecked_time_subtraction)]
 #![deny(clippy::unnecessary_wraps)]
 #![warn(clippy::unseparated_literal_suffix)]
 #![deny(clippy::unwrap_used)]
@@ -91,7 +91,7 @@ semipublic_mod! {
     mod onion_proxy;
     mod process;
     mod reload_cfg;
-    mod socks;
+    mod proxy;
 }
 #[cfg_attr(not(feature = "rpc"), path = "rpc_stub.rs")]
 mod rpc;
@@ -270,9 +270,10 @@ where
             .subcommand(
                 Command::new("proxy")
                     .about(
-                        "Run Arti in SOCKS proxy mode, proxying connections through the Tor network.",
+                        "Run Arti in proxy mode, proxying connections through the Tor network.",
                     )
                     .arg(
+                        // TODO: Allow a proxy-port alias for this too, once http-connect is stable.
                         Arg::new("socks-port")
                             .short('p')
                             .action(ArgAction::Set)
