@@ -10,8 +10,8 @@ use futures::{select_biased, FutureExt as _, Stream};
 use tor_config::file_watcher::{self, FileWatcherBuilder, FileEventSender, FileWatcher};
 use tor_config::{sources::FoundConfigFiles, ConfigurationSource, ConfigurationSources};
 use tor_rtcompat::Runtime;
-use tracing::{debug, error, info, warn};
-use futures::task::SpawnExt;
+use tracing::{debug, error, info, instrument, warn};
+use tor_rtcompat::SpawnExt;
 use futures::StreamExt;
 
 #[cfg(target_family = "unix")]
@@ -55,6 +55,7 @@ pub(crate) trait ReconfigurableModule: Send + Sync {
 ///
 /// See the [`FileWatcher`](FileWatcher#Limitations) docs for limitations.
 #[cfg_attr(feature = "experimental-api", visibility::make(pub))]
+#[instrument(level = "trace", skip_all)]
 pub(crate) fn watch_for_config_changes<R: Runtime>(
     runtime: &R,
     sources: ConfigurationSources,
@@ -96,6 +97,7 @@ pub(crate) fn watch_for_config_changes<R: Runtime>(
 ///
 /// Spawned from `watch_for_config_changes`.
 #[allow(clippy::cognitive_complexity)] // TODO: Refactor? Partly due to tracing.
+#[instrument(level = "trace", skip_all)]
 async fn run_watcher<R: Runtime>(
     runtime: R,
     sources: ConfigurationSources,
@@ -162,6 +164,7 @@ async fn run_watcher<R: Runtime>(
 
 /// Reload the configuration.
 #[allow(clippy::cognitive_complexity)] // TODO: Refactor? Partly due to tracing.
+#[instrument(level = "trace", skip_all)]
 async fn reload_configuration<R: Runtime>(
     runtime: R,
     mut watcher: Option<FileWatcher>,
@@ -211,6 +214,7 @@ async fn reload_configuration<R: Runtime>(
 }
 
 impl<R: Runtime> ReconfigurableModule for TorClient<R> {
+    #[instrument(level = "trace", skip_all)]
     fn reconfigure(&self, new: &ArtiCombinedConfig) -> anyhow::Result<()> {
         TorClient::reconfigure(self, &new.1, Reconfigure::WarnOnFailures)?;
         Ok(())
@@ -240,6 +244,7 @@ impl ReconfigurableModule for Application {
     // TODO: This should probably take "how: Reconfigure" as an argument, and
     // pass it down as appropriate. See issue #1156.
     #[allow(clippy::cognitive_complexity)]
+    #[instrument(level = "trace", skip_all)]
     fn reconfigure(&self, new: &ArtiCombinedConfig) -> anyhow::Result<()> {
         let original = &self.original_config;
         let config = &new.0;
@@ -291,6 +296,7 @@ fn prepare<'a, R: Runtime>(
 //
 // TODO: This should probably take "how: Reconfigure" as an argument, and
 // pass it down as appropriate. See issue #1156.
+#[instrument(level = "trace", skip_all)]
 fn reconfigure(
     found_files: FoundConfigFiles<'_>,
     reconfigurable: &[Weak<dyn ReconfigurableModule>],
@@ -323,7 +329,7 @@ mod test {
     #![allow(clippy::print_stdout)]
     #![allow(clippy::single_char_pattern)]
     #![allow(clippy::unwrap_used)]
-    #![allow(clippy::unchecked_duration_subtraction)]
+    #![allow(clippy::unchecked_time_subtraction)]
     #![allow(clippy::useless_vec)]
     #![allow(clippy::needless_pass_by_value)]
     //! <!-- @@ end test lint list maintained by maint/add_warning @@ -->
