@@ -3,11 +3,10 @@
 //! This module is unfortunately necessary as a middleware due to some obscure
 //! things in Tor, most notably the ".z" extensions.
 
-#[allow(unused_imports)]
-use std::pin::Pin;
+use cache::StoreCache;
+use r2d2::Pool;
+use r2d2_sqlite::SqliteConnectionManager;
 use strum::EnumString;
-#[allow(unused_imports)]
-use tokio::sync::RwLock;
 use tor_error::internal;
 
 use std::{
@@ -15,14 +14,12 @@ use std::{
     convert::Infallible,
     panic::{catch_unwind, AssertUnwindSafe},
     str::FromStr,
-    sync::{Arc, Mutex, Weak},
+    sync::Arc,
     task::{Context, Poll},
     time::Duration,
 };
 
 use bytes::Bytes;
-use deadpool::managed::Pool;
-use deadpool_sqlite::Manager;
 use futures::{Stream, StreamExt};
 use http::{header, Method, Request, Response, StatusCode};
 use http_body::{Body, Frame};
@@ -39,12 +36,10 @@ use tokio::{
     time,
 };
 use tracing::warn;
-use weak_table::WeakValueHashMap;
 
-use crate::{
-    err::{BuilderError, DatabaseError, StoreCacheError},
-    schema::Sha256,
-};
+use crate::database::{self, sql, Sha256};
+
+mod cache;
 
 /// A type alias for the functions implementing endpoint logic.
 ///
@@ -102,51 +97,41 @@ struct DocumentBody(VecDeque<Arc<[u8]>>);
 /// Representation of an endpoint, uniquely identified by a [`Method`] and path
 /// pair followed by an appropriate [`EndpointFn`].
 ///
-/// TODO: Replace the [`Vec`] with a [`str`] and do splitting in the core code.
-type Endpoint = (Method, Vec<&'static str>, EndpointFn);
+/// The path itself is a special string that refers to the endpoint at which this
+/// resource should be available.  It supports a pattern-matching like syntax
+/// through the use of the asterisk `*` character.
+///
+/// For example:
+/// `/tor/status-vote/current/consensus` will match the URL exactly, whereas
+/// `/tor/status-vote/current/*` will match every string that is in the
+/// fourth component; such as `/tor/status-vote/current/consensus` or
+/// `/tor/status-vote/current/consensus-microdesc`; it will however not
+/// match in a prefix-like syntax, such as
+/// `/tor/status-vote/current/consensus-microdesc/diff`.
+///
+/// In the case of non-unique matches, the first match wins.  Also, because
+/// of wildcards, matching takes place in a `O(n)` fashion, so be sure to
+/// to keep the `n` at a reasonable size.  This should not be much of a
+/// problem for Tor applications though, because the list of endpoints is
+/// reasonable (less than 30).
+///
+/// TODO: The entire asterisk matching is not so super nice, primarily because
+/// it removes compile-time semantic checks; however, I cannot really think
+/// of a much cleaner way that would not involve lots of boilerplate.
+/// The most minimal "clean" way could be to do `path: &Option<&'static str>`
+/// but I am not sure if this overhead is worth it, i.e.:
+/// * `/tor/status-vote/current/*/diff/*/*`
+/// * `[Some(""), Some("tor"), Some("status-vote"), Some("current"), None, ...]`
+///   Maybe a macro could help here though ...
+type Endpoint = (Method, &'static str, EndpointFn);
 
 /// Representation of the core HTTP server.
+#[derive(Debug)]
 pub(crate) struct HttpServer {
-    /// The [`HttpServerBuilder`] used to generate this [`HttpServer`].
-    builder: HttpServerBuilder,
-}
-
-/// A builder for [`HttpServer`].
-///
-/// TODO DIRMIRROR: Get rid of this structure and just access the stuff in
-/// [`HttpServer`] directly, which is fine given that this is an internal module
-/// anyways.
-#[derive(Default)]
-pub(crate) struct HttpServerBuilder {
-    /// The [`Pool`] from deapool to manage database connections.
-    pool: Option<Pool<Manager>>,
-    /// The HTTP endpoints.
+    /// List of [`Endpoint`] entries.
     endpoints: Vec<Endpoint>,
-}
-
-/// Representation of the store cache.
-///
-/// The cache serves the purpose to not store the same document multiple times
-/// in memory, when multiple clients request it simultanously.
-///
-/// It *DOES NOT* serve the purpose to reduce the amount of read system calls.
-/// We believe that SQLite and the operating system itself do a good job at
-/// buffering reads for us here.
-///
-/// The cache itself is wrapped in an [`Arc`] as well as in a [`Mutex`],
-/// meaning it is safe to share and access around threads/tasks.
-///
-/// All hash lookups in the `store` table should be performed through this
-/// interface, because it will automatically select them from the database in
-/// case they are missing.
-#[derive(Debug, Clone)]
-pub(crate) struct StoreCache {
-    /// The actual data of the cache.
-    ///
-    /// We use a [`Mutex`] instead of an [`RwLock`], because we want to assure
-    /// that a concurrent cache miss does not lead into two simultanous database
-    /// reads and copies into memory.
-    data: Arc<Mutex<WeakValueHashMap<Sha256, Weak<[u8]>>>>,
+    /// Access to the database pool.
+    pool: Pool<SqliteConnectionManager>,
 }
 
 impl Body for DocumentBody {
@@ -166,9 +151,10 @@ impl Body for DocumentBody {
 }
 
 impl HttpServer {
-    /// Creates a new [`HttpServerBuilder`].
-    pub(crate) fn builder() -> HttpServerBuilder {
-        HttpServerBuilder::default()
+    /// Creates a new [`HttpServer`] with a given [`Vec`] of [`Endpoint`] entries
+    /// alongside access to the database [`Pool`].
+    pub(crate) fn new(endpoints: Vec<Endpoint>, pool: Pool<SqliteConnectionManager>) -> Self {
+        Self { endpoints, pool }
     }
 
     /// Runs the server endlessly in the current task.
@@ -177,15 +163,15 @@ impl HttpServer {
     /// occur, occur in further sub-tasks spawned by it and handled appropriately,
     /// that is ususally logging the error and continuing the exeuction.
     #[allow(clippy::cognitive_complexity)]
-    pub(crate) async fn serve<I, S, E>(self, mut listener: I) -> Result<(), Infallible>
+    pub(crate) async fn serve<I, S, E>(self, mut listener: I) -> Result<(), tor_error::Bug>
     where
         I: Stream<Item = Result<S, E>> + Unpin,
         S: AsyncRead + AsyncWrite + Unpin + Send + 'static,
         E: std::error::Error,
     {
-        let cache = StoreCache::new();
-        let endpoints: Arc<[Endpoint]> = self.builder.endpoints.into();
-        let pool = self.builder.pool.expect("builder ensured this is Some");
+        let cache = Arc::new(StoreCache::new());
+        let endpoints: Arc<[Endpoint]> = self.endpoints.into();
+        let pool = self.pool;
 
         // We operate exclusively in JoinSets so that everything gets aborted
         // nicely in order without causing any sort of leaks.
@@ -195,13 +181,10 @@ impl HttpServer {
         // Spawn a simple garbage collection task that periodically removes
         // dead references, just in case, from the StoreCache.
         misc_tasks.spawn({
-            let mut cache = cache.clone();
+            let cache = cache.clone();
             async move {
                 loop {
-                    match cache.gc() {
-                        Ok(()) => {}
-                        Err(e) => warn!("gc failed: {e}"),
-                    };
+                    cache.gc();
                     time::sleep(Duration::from_secs(60)).await;
                 }
             }
@@ -220,8 +203,7 @@ impl HttpServer {
                     }
 
                     // This should not happen due to ownership.
-                    // TODO DIRMIRROR: Replace this with an error by all means.
-                    None => unreachable!("listener was closed externally?"),
+                    None => return Err(internal!("listener was closed externally?")),
                 },
 
                 // A hyper task we monitored in our tasks has exiteed.
@@ -242,9 +224,9 @@ impl HttpServer {
 
     /// Dispatches a new [`Stream`] into an existing [`JoinSet`].
     fn dispatch_stream<S: AsyncRead + AsyncWrite + Unpin + Send + 'static>(
-        cache: &StoreCache,
+        cache: &Arc<StoreCache>,
         endpoints: &Arc<[Endpoint]>,
-        pool: &Pool<Manager>,
+        pool: &Pool<SqliteConnectionManager>,
         tasks: &mut JoinSet<Result<(), hyper::Error>>,
         stream: S,
     ) {
@@ -271,47 +253,25 @@ impl HttpServer {
         tasks.spawn(http1::Builder::new().serve_connection(stream, service));
     }
 
-    /// A small wrapper function that creates a [`Transaction`] and continues
-    /// execution in [`Self::handler_tx`].
+    /// A small wrapper function that creates a read-only or read-write
+    /// [`Transaction`] based upon the [`Method`] and continues execution in
+    /// [`Self::handler_tx`].
     async fn handler(
-        cache: StoreCache,
+        cache: Arc<StoreCache>,
         endpoints: Arc<[Endpoint]>,
-        pool: Pool<Manager>,
+        pool: Pool<SqliteConnectionManager>,
         requ: Request<Incoming>,
     ) -> Result<Response<DocumentBody>, Infallible> {
-        // Obtain a database pool object (database connection).
-        let conn = match pool.get().await {
-            Ok(conn) => conn,
-            Err(e) => {
-                warn!("database pool error: {e}");
-                return Ok(Self::empty_response(StatusCode::INTERNAL_SERVER_ERROR));
-            }
-        };
-
-        // Create a transaction and pass it to `handler_tx`.
-        let res = conn
-            .interact(move |conn| {
-                let tx = match conn.transaction() {
-                    Ok(tx) => tx,
-                    Err(e) => {
-                        warn!("transaction creation error: {e}");
-                        return Ok(Self::empty_response(StatusCode::INTERNAL_SERVER_ERROR));
-                    }
-                };
-
-                let res = Self::handler_tx(cache, &endpoints, tx, &requ);
-                Ok(res)
-            })
-            .await;
-
-        // Compose the result.
-        match res {
-            Ok(res) => res,
-            Err(e) => {
-                warn!("endpoint function error: {e}");
-                Ok(Self::empty_response(StatusCode::INTERNAL_SERVER_ERROR))
-            }
-        }
+        // TODO: This would be the place to either use read_tx or rw_tx depending
+        // on the method, but given that this is all GET at the moment, just go
+        // with read_tx.
+        Ok(
+            database::read_tx(&pool, |tx| Self::handler_tx(&cache, &endpoints, tx, &requ))
+                .unwrap_or_else(|e| {
+                    warn!("database error: {e}");
+                    Self::empty_response(StatusCode::INTERNAL_SERVER_ERROR)
+                }),
+        )
     }
 
     /// A big monolithic function that handles incoming request with a consist
@@ -326,14 +286,13 @@ impl HttpServer {
     /// 5. Query the [`StoreCache`] with the [`Sha256`] and [`Transaction`] handle
     ///    to store the document ref
     /// 6. Compose the [`Response`]
-    /// 7. Commit or drop the transaction, based on the [`Method`]
     ///
     /// TODO DIRMIRROR: Implement [`Method::HEAD`].
     #[allow(clippy::cognitive_complexity)]
     fn handler_tx(
-        mut cache: StoreCache,
+        cache: &Arc<StoreCache>,
         endpoints: &[Endpoint],
-        tx: Transaction,
+        tx: &Transaction,
         requ: &Request<Incoming>,
     ) -> Response<DocumentBody> {
         // (1) Determine the compression algorithm
@@ -349,7 +308,7 @@ impl HttpServer {
         };
 
         // (3) Call the `EndpointFn` to obtain various `Sha256` hashsums
-        let endpoint_fn_resp = match catch_unwind(AssertUnwindSafe(|| endpoint_fn(&tx, requ))) {
+        let endpoint_fn_resp = match catch_unwind(AssertUnwindSafe(|| endpoint_fn(tx, requ))) {
             // Everything went successful.
             Ok(Ok(r)) => r,
 
@@ -378,7 +337,7 @@ impl HttpServer {
         // (4) Map the sha256sums to their compressed counterpart
         let sha256sums = sha256sums
             .iter()
-            .map(|sha256| Self::map_encoding(&tx, sha256, encoding))
+            .map(|sha256| Self::map_encoding(tx, sha256, encoding))
             .collect::<Result<Vec<_>, _>>();
         let sha256sums = match sha256sums {
             Ok(s) => s,
@@ -396,7 +355,7 @@ impl HttpServer {
         //     to store the document ref
         let mut documents = VecDeque::new();
         for sha256 in &sha256sums {
-            let document = match cache.get(&tx, sha256) {
+            let document = match cache.get(tx, sha256) {
                 Ok(document) => document,
                 Err(e) => {
                     warn!(
@@ -428,14 +387,6 @@ impl HttpServer {
             );
         }
 
-        // (7) Commit or drop the transaction, based on the `Method`
-        //
-        // For now, we just drop it.
-        match tx.rollback() {
-            Ok(()) => {}
-            Err(e) => warn!("rollback error: {e}"),
-        }
-
         resp
     }
 
@@ -535,6 +486,7 @@ impl HttpServer {
         let mut res = None;
         for tuple in endpoints.iter() {
             let (method, path, _endpoint_fn) = tuple;
+            let path = path.split('/').collect::<Vec<_>>();
 
             // Filter the method out first.
             if requ.method() != method {
@@ -592,7 +544,7 @@ impl HttpServer {
         tx: &Transaction,
         sha256: &Sha256,
         encoding: ContentEncoding,
-    ) -> Result<Sha256, DatabaseError> {
+    ) -> Result<Sha256, rusqlite::Error> {
         let sha256 = sha256.clone();
 
         // If the encoding is the identity, do not bother about it any further.
@@ -600,12 +552,14 @@ impl HttpServer {
             return Ok(sha256);
         }
 
-        let mut stmt = tx.prepare_cached(
+        let mut stmt = tx.prepare_cached(sql!(
             "
-        SELECT compressed_sha256
-        FROM compressed_document
-        WHERE identity_sha256 = ?1 AND algorithm = ?2",
-        )?;
+            SELECT compressed_sha256
+            FROM compressed_document
+              WHERE identity_sha256 = ?1
+                AND algorithm = ?2
+            "
+        ))?;
         let compressed_sha256 =
             stmt.query_one(params![sha256, encoding.to_string()], |row| row.get(0))?;
 
@@ -622,126 +576,8 @@ impl HttpServer {
     }
 }
 
-impl HttpServerBuilder {
-    /// Creates a new [`HttpServerBuilder`] with default values.
-    pub(crate) fn new() -> Self {
-        Self::default()
-    }
-
-    /// Sets the database pool which is mandatory.
-    pub(crate) fn pool(mut self, pool: Pool<Manager>) -> Self {
-        self.pool = Some(pool);
-        self
-    }
-
-    /// Adds a new [`Method::GET`] endpoint.
-    ///
-    /// `path` is a special string that refers to the endpoint at which this
-    /// resource should be available.  It supports a pattern-matching like
-    /// syntax through the use of the asterisk `*` character.
-    ///
-    /// For example:
-    /// `/tor/status-vote/current/consensus` will match the URL exactly, whereas
-    /// `/tor/status-vote/current/*` will match every string that is in the
-    /// fourth component; such as `/tor/status-vote/current/consensus` or
-    /// `/tor/status-vote/current/consensus-microdesc`; it will however not
-    /// match in a prefix-like syntax, such as
-    /// `/tor/status-vote/current/consensus-microdesc/diff`.
-    ///
-    /// In the case of non-unique matches, the first match wins.  Also, because
-    /// of wildcards, matching takes place in a `O(n)` fashion, so be sure to
-    /// to keep the `n` at a reasonable size.  This should not be much of a
-    /// problem for Tor applications though, because the list of endpoints is
-    /// reasonable (less than 30).
-    ///
-    /// TODO: The entire asterisk matching is not so super nice, primarily because
-    /// it removes compile-time semantic checks; however, I cannot really think
-    /// of a much cleaner way that would not involve lots of boilerplate.
-    /// The most minimal "clean" way could be to do `path: &Option<&'static str>`
-    /// but I am not sure if this overhead is worth it, i.e.:
-    /// * `/tor/status-vote/current/*/diff/*/*`
-    /// * `[Some(""), Some("tor"), Some("status-vote"), Some("current"), None, ...]`
-    ///   Maybe a macro could help here though ...
-    pub(crate) fn get(mut self, path: &'static str, endpoint_fn: EndpointFn) -> Self {
-        self.endpoints
-            .push((Method::GET, path.split('/').collect(), endpoint_fn));
-        self
-    }
-
-    /// Consumes the [`HttpServerBuilder`] to build an [`HttpServer`].
-    pub(crate) fn build(self) -> Result<HttpServer, BuilderError> {
-        // Check the presence of mandatory fields.
-        if self.pool.is_none() {
-            return Err(BuilderError::MissingField("pool"));
-        }
-
-        Ok(HttpServer { builder: self })
-    }
-}
-
-impl StoreCache {
-    /// Creates a new empty [`StoreCache`].
-    pub(crate) fn new() -> Self {
-        Self {
-            data: Arc::new(Mutex::new(WeakValueHashMap::new())),
-        }
-    }
-
-    /// Removes all mappings whose values have expired.
-    ///
-    /// Takes O(n) time.
-    pub(crate) fn gc(&mut self) -> Result<(), StoreCacheError> {
-        self.data
-            .lock()
-            .map_err(|_| internal!("poisoned lock"))?
-            .remove_expired();
-        Ok(())
-    }
-
-    /// Looks up a [`Sha256`] in the cache or the database.
-    ///
-    /// If we got a cache miss, this function automatically queries the database
-    /// and inserts the result into the cache, before returning it.
-    pub(crate) fn get(
-        &mut self,
-        tx: &Transaction,
-        sha256: &Sha256,
-    ) -> Result<Arc<[u8]>, StoreCacheError> {
-        // TODO DIRMIRROR: Do we want to keep the lock while doing db queries?
-        let mut lock = self.data.lock().map_err(|_| internal!("poisoned lock"))?;
-
-        // Query the cache for the relevant document.
-        if let Some(document) = lock.get(sha256) {
-            return Ok(document);
-        }
-
-        // Cache miss, let us query the database.
-        let document = Self::get_db(tx, sha256)?;
-
-        // Insert it into the cache.
-        lock.insert(sha256.clone(), document.clone());
-
-        Ok(document)
-    }
-
-    /// Obtains a [`Sha256`] from the database without consulting the cache first.
-    ///
-    /// TODO DIRMIRROR: This function is only intended for use in [`StoreCache::get`].
-    /// Consider to either remove it entirely or move [`StoreCache`] into its own
-    /// module.
-    fn get_db(tx: &Transaction, sha256: &Sha256) -> Result<Arc<[u8]>, StoreCacheError> {
-        let mut stmt = tx
-            .prepare_cached("SELECT content FROM store WHERE sha256 = ?1")
-            .map_err(DatabaseError::from)?;
-        let document: Vec<u8> = stmt
-            .query_one(params![sha256], |row| row.get(0))
-            .map_err(DatabaseError::from)?;
-        Ok(Arc::from(document))
-    }
-}
-
 #[cfg(test)]
-mod test {
+pub(in crate::http) mod test {
     // @@ begin test lint list maintained by maint/add_warning @@
     #![allow(clippy::bool_assert_comparison)]
     #![allow(clippy::clone_on_copy)]
@@ -751,10 +587,12 @@ mod test {
     #![allow(clippy::print_stdout)]
     #![allow(clippy::single_char_pattern)]
     #![allow(clippy::unwrap_used)]
-    #![allow(clippy::unchecked_duration_subtraction)]
+    #![allow(clippy::unchecked_time_subtraction)]
     #![allow(clippy::useless_vec)]
     #![allow(clippy::needless_pass_by_value)]
     //! <!-- @@ end test lint list maintained by maint/add_warning @@ -->
+    use crate::database;
+
     use super::*;
 
     use std::{
@@ -762,14 +600,12 @@ mod test {
         str::FromStr,
     };
 
-    use deadpool_sqlite::Config;
     use flate2::{
         write::{DeflateDecoder, DeflateEncoder, GzEncoder},
         Compression,
     };
     use http::Version;
     use http_body_util::{BodyExt, Empty};
-    use rusqlite::Connection;
     use sha2::{digest::Update, Digest};
     use tokio::{
         net::{TcpListener, TcpStream},
@@ -777,41 +613,25 @@ mod test {
     };
     use tokio_stream::wrappers::TcpListenerStream;
 
-    use crate::schema::prepare_db;
-
-    const IDENTITY: &str = "Lorem ipsum dolor sit amet.";
-    const IDENTITY_SHA256: &str =
+    pub(in crate::http) const IDENTITY: &str = "Lorem ipsum dolor sit amet.";
+    pub(in crate::http) const IDENTITY_SHA256: &str =
         "DD14CBBF0E74909AAC7F248A85D190AFD8DA98265CEF95FC90DFDDABEA7C2E66";
-    const DEFLATE_SHA256: &str = "07564DD13A7F4A6AD98B997F2938B1CEE11F8C7F358C444374521BA54D50D05E";
-    const GZIP_SHA256: &str = "1518107D3EF1EC6EAC3F3249DF26B2F845BC8226C326309F4822CAEF2E664104";
-    const XZ_STD_SHA256: &str = "17416948501F8E627CC9A8F7EFE7A2F32788D53CB84A5F67AC8FD4C1B59184CF";
-    const X_TOR_LZMA_SHA256: &str =
+    pub(in crate::http) const DEFLATE_SHA256: &str =
+        "07564DD13A7F4A6AD98B997F2938B1CEE11F8C7F358C444374521BA54D50D05E";
+    pub(in crate::http) const GZIP_SHA256: &str =
+        "1518107D3EF1EC6EAC3F3249DF26B2F845BC8226C326309F4822CAEF2E664104";
+    pub(in crate::http) const XZ_STD_SHA256: &str =
+        "17416948501F8E627CC9A8F7EFE7A2F32788D53CB84A5F67AC8FD4C1B59184CF";
+    pub(in crate::http) const X_TOR_LZMA_SHA256: &str =
         "B5549F79A69113BDAF3EF0AD1D7D339D0083BC31400ECEE1B673F331CF26E239";
 
-    async fn create_test_db_pool() -> Pool<Manager> {
-        let pool = Config::new("")
-            .create_pool(deadpool::Runtime::Tokio1)
-            .unwrap();
-
-        pool.get()
-            .await
-            .unwrap()
-            .interact(init_test_db)
-            .await
-            .unwrap();
-
+    pub(in crate::http) fn create_test_db_pool() -> Pool<SqliteConnectionManager> {
+        let pool = database::open("").unwrap();
+        database::rw_tx(&pool, init_test_db).unwrap();
         pool
     }
 
-    fn create_test_db_connection() -> Connection {
-        let mut conn = Connection::open_in_memory().unwrap();
-        init_test_db(&mut conn);
-        conn
-    }
-
-    fn init_test_db(conn: &mut Connection) {
-        prepare_db(conn).unwrap();
-
+    fn init_test_db(tx: &Transaction) {
         // Create a document and compressed versions of it.
         let identity_sha256 = hex::encode_upper(sha2::Sha256::new().chain(IDENTITY).finalize());
         assert_eq!(identity_sha256, IDENTITY_SHA256);
@@ -842,16 +662,17 @@ mod test {
             hex::encode_upper(sha2::Sha256::new().chain(&x_tor_lzma).finalize());
         assert_eq!(x_tor_lzma_sha256, X_TOR_LZMA_SHA256);
 
-        let tx = conn.transaction().unwrap();
         tx.execute(
-            "
-                        INSERT INTO store(sha256, content) VALUES
-                        (?1, ?2), -- identity
-                        (?3, ?4), -- deflate
-                        (?5, ?6), -- gzip
-                        (?7, ?8), -- xzstd
-                        (?9, ?10); -- lzma
-                    ",
+            sql!(
+                "
+                INSERT INTO store(sha256, content) VALUES
+                (?1, ?2), -- identity
+                (?3, ?4), -- deflate
+                (?5, ?6), -- gzip
+                (?7, ?8), -- xzstd
+                (?9, ?10) -- lzma
+                "
+            ),
             params![
                 identity_sha256,
                 IDENTITY.as_bytes().to_vec(),
@@ -867,16 +688,25 @@ mod test {
         )
         .unwrap();
 
-        tx.execute("
+        tx.execute(
+            sql!(
+                "
                 INSERT INTO compressed_document(algorithm, identity_sha256, compressed_sha256) VALUES
                 ('deflate', ?1, ?2),
                 ('gzip', ?1, ?3),
                 ('x-zstd', ?1, ?4),
-                ('x-tor-lzma', ?1, ?5);
-                ",
-                params![identity_sha256, deflate_sha256, gzip_sha256, xz_std_sha256, x_tor_lzma_sha256]).unwrap();
-
-        tx.commit().unwrap();
+                ('x-tor-lzma', ?1, ?5)
+                "
+            ),
+            params![
+                identity_sha256,
+                deflate_sha256,
+                gzip_sha256,
+                xz_std_sha256,
+                x_tor_lzma_sha256
+            ],
+        )
+        .unwrap();
     }
 
     #[test]
@@ -986,10 +816,10 @@ mod test {
         }
 
         let endpoints: Vec<Endpoint> = vec![
-            (Method::GET, vec!["", "foo", "bar", "baz"], dummy),
-            (Method::GET, vec!["", "foo", "*", "baz"], dummy),
-            (Method::GET, vec!["", "bar", "*"], dummy),
-            (Method::GET, vec!["", ""], dummy),
+            (Method::GET, "/foo/bar/baz", dummy),
+            (Method::GET, "/foo/*/baz", dummy),
+            (Method::GET, "/bar/*", dummy),
+            (Method::GET, "/", dummy),
         ];
 
         /// Basically a domain specific [`assert_eq`] that works by comparing
@@ -1035,7 +865,7 @@ mod test {
 
     #[test]
     fn map_encoding() {
-        let mut conn = create_test_db_connection();
+        let pool = create_test_db_pool();
 
         let data = [
             (ContentEncoding::Identity, IDENTITY_SHA256),
@@ -1045,14 +875,16 @@ mod test {
             (ContentEncoding::XTorLzma, X_TOR_LZMA_SHA256),
         ];
 
-        let tx = conn.transaction().unwrap();
-        for (encoding, compressed_sha256) in data {
-            println!("{encoding}");
-            assert_eq!(
-                HttpServer::map_encoding(&tx, &IDENTITY_SHA256.to_string(), encoding).unwrap(),
-                compressed_sha256
-            );
-        }
+        database::read_tx(&pool, |tx| {
+            for (encoding, compressed_sha256) in data {
+                println!("{encoding}");
+                assert_eq!(
+                    HttpServer::map_encoding(tx, &IDENTITY_SHA256.to_string(), encoding).unwrap(),
+                    compressed_sha256
+                );
+            }
+        })
+        .unwrap();
     }
 
     #[tokio::test]
@@ -1066,12 +898,11 @@ mod test {
             Ok(Response::new(vec![IDENTITY_SHA256.into()]))
         }
 
-        let pool = create_test_db_pool().await;
-        let server = HttpServer::builder()
-            .pool(pool)
-            .get("/tor/status-vote/current/consensus", identity)
-            .build()
-            .unwrap();
+        let pool = create_test_db_pool();
+        let server = HttpServer::new(
+            vec![(Method::GET, "/tor/status-vote/current/consensus", identity)],
+            pool,
+        );
 
         let listener = TcpListener::bind("[::]:0").await.unwrap();
         let local_addr = listener.local_addr().unwrap();
@@ -1122,55 +953,4 @@ mod test {
         let decoded_resp = decoder.finish().unwrap();
         assert_eq!(IDENTITY, String::from_utf8_lossy(&decoded_resp));
     }
-
-    #[test]
-    fn store_cache() {
-        let mut conn = create_test_db_connection();
-        let mut cache = StoreCache::new();
-
-        let tx = conn.transaction().unwrap();
-
-        // Obtain the lipsum entry.
-        let entry = cache.get(&tx, &String::from(IDENTITY_SHA256)).unwrap();
-        assert_eq!(entry.as_ref(), IDENTITY.as_bytes());
-        assert_eq!(Arc::strong_count(&entry), 1);
-
-        // Obtain the lipsum entry again but ensure it is not copied in memory.
-        let entry2 = cache.get(&tx, &String::from(IDENTITY_SHA256)).unwrap();
-        assert_eq!(Arc::strong_count(&entry), 2);
-        assert_eq!(Arc::as_ptr(&entry), Arc::as_ptr(&entry2));
-        assert_eq!(entry, entry2);
-
-        // Perform a garbage collection and ensure that entry is not removed.
-        assert!(cache
-            .data
-            .lock()
-            .unwrap()
-            .contains_key(&String::from(IDENTITY_SHA256)));
-        cache.gc().unwrap();
-        assert!(cache
-            .data
-            .lock()
-            .unwrap()
-            .contains_key(&String::from(IDENTITY_SHA256)));
-
-        // Now drop entry and entry2 and perform the gc again.
-        let weak_entry = Arc::downgrade(&entry);
-        assert_eq!(weak_entry.strong_count(), 2);
-        drop(entry);
-        drop(entry2);
-        assert_eq!(weak_entry.strong_count(), 0);
-
-        // The strong count zero should already make it impossible to access the element ...
-        assert!(!cache
-            .data
-            .lock()
-            .unwrap()
-            .contains_key(&String::from(IDENTITY_SHA256)));
-        // ... but it should not reduce the total size of the hash map ...
-        assert_eq!(cache.data.lock().unwrap().len(), 1);
-        cache.gc().unwrap();
-        // ... however, the garbage collection should actually do.
-        assert_eq!(cache.data.lock().unwrap().len(), 0);
-    }
 }
