@@ -30,7 +30,7 @@
 #![deny(clippy::ref_option_ref)]
 #![warn(clippy::semicolon_if_nothing_returned)]
 #![warn(clippy::trait_duplication_in_bounds)]
-#![deny(clippy::unchecked_duration_subtraction)]
+#![deny(clippy::unchecked_time_subtraction)]
 #![deny(clippy::unnecessary_wraps)]
 #![warn(clippy::unseparated_literal_suffix)]
 #![deny(clippy::unwrap_used)]
@@ -54,7 +54,7 @@
 //     filtered
 
 use futures::channel::mpsc;
-use futures::task::SpawnExt;
+use itertools::Either;
 use serde::{Deserialize, Serialize};
 use std::collections::HashMap;
 use std::net::SocketAddr;
@@ -65,6 +65,7 @@ use tor_error::internal;
 use tor_linkspec::{OwnedChanTarget, OwnedCircTarget, RelayId, RelayIdSet};
 use tor_netdir::NetDirProvider;
 use tor_proto::ClockSkew;
+use tor_rtcompat::SpawnExt;
 use tor_units::BoundedInt32;
 use tracing::{debug, info, instrument, trace, warn};
 
@@ -324,6 +325,7 @@ impl<R: Runtime> GuardMgr<R> {
     ///
     /// It won't be able to hand out any guards until a [`NetDirProvider`] has
     /// been installed.
+    #[instrument(skip_all, level = "trace")]
     pub fn new<S>(
         runtime: R,
         state_mgr: S,
@@ -474,6 +476,7 @@ impl<R: Runtime> GuardMgr<R> {
     ///
     /// We only call this method if we _don't_ have the lock on the state
     /// files.  If we have the lock, we only want to save.
+    #[instrument(level = "trace", skip_all)]
     pub fn reload_persistent_state(&self) -> Result<(), GuardMgrError> {
         let mut inner = self.inner.lock().expect("Poisoned lock");
         if let Some(new_guards) = inner.storage.load()? {
@@ -485,6 +488,7 @@ impl<R: Runtime> GuardMgr<R> {
     /// Switch from having an unowned persistent state to having an owned one.
     ///
     /// Requires that we hold the lock on the state files.
+    #[instrument(level = "trace", skip_all)]
     pub fn upgrade_to_owned_persistent_state(&self) -> Result<(), GuardMgrError> {
         let mut inner = self.inner.lock().expect("Poisoned lock");
         debug_assert!(inner.storage.can_store());
@@ -539,6 +543,7 @@ impl<R: Runtime> GuardMgr<R> {
     }
 
     /// Replace the configuration in this `GuardMgr` with `config`.
+    #[instrument(level = "trace", skip_all)]
     pub fn reconfigure(
         &self,
         config: &impl GuardMgrConfig,
@@ -586,6 +591,7 @@ impl<R: Runtime> GuardMgr<R> {
     /// through the guard returned by this function, but you can't
     /// actually use it for traffic unless the [`GuardUsable`] future
     /// yields "true".
+    #[instrument(skip_all, level = "trace")]
     pub fn select_guard(
         &self,
         usage: GuardUsage,
@@ -898,6 +904,7 @@ impl GuardMgrInner {
 
     /// Replace our bridge configuration with the one from `new_config`.
     #[cfg(feature = "bridge-client")]
+    #[instrument(level = "trace", skip_all)]
     fn replace_bridge_config(
         &mut self,
         new_config: &impl GuardMgrConfig,
@@ -1021,9 +1028,8 @@ impl GuardMgrInner {
             // But due to the other check in `netdir_is_sufficient`, we
             // shouldn't be installing a netdir until it has microdescs for all
             // of the (non-bridge) primary guards that it lists. - nickm
-            if active_guards.n_primary_without_id_info_in(universe) > 0
-                && universe_type == UniverseType::NetDir
-            {
+            let n = active_guards.n_primary_without_id_info_in(universe);
+            if n > 0 && universe_type == UniverseType::NetDir {
                 // We are missing the information from a NetDir needed to see
                 // whether our primary guards are listed, so we shouldn't update
                 // our guard status.
@@ -1034,11 +1040,16 @@ impl GuardMgrInner {
                 // (When a bridge desc is missing, the bridge could be down or
                 // unreachable, and nobody else can help us. But if a microdesc
                 // is missing, we just need to find a cache that has it.)
+                trace!(
+                    n_primary_without_id_info = n,
+                    "Not extending guardset, missing information."
+                );
                 return ExtendedStatus::No;
             }
             active_guards.update_status_from_dir(universe);
             active_guards.extend_sample_as_needed(now, params, universe)
         } else {
+            trace!("Not extending guardset, no universe given.");
             ExtendedStatus::No
         };
 
@@ -1073,6 +1084,7 @@ impl GuardMgrInner {
 
     /// Replace the active guard state with `new_state`, preserving
     /// non-persistent state for any guards that are retained.
+    #[instrument(level = "trace", skip_all)]
     fn replace_guards_with(
         &mut self,
         mut new_guards: GuardSets,
@@ -1153,6 +1165,7 @@ impl GuardMgrInner {
     }
 
     /// Replace the current GuardFilter with `filter`.
+    #[instrument(level = "trace", skip_all)]
     fn set_filter(&mut self, filter: GuardFilter, wallclock: SystemTime, now: Instant) {
         self.filter = filter;
         self.update(wallclock, now);
@@ -1438,6 +1451,7 @@ impl GuardMgrInner {
     }
 
     /// Try to select a guard, expanding the sample if the first attempt fails.
+    #[instrument(skip_all, level = "trace")]
     fn select_guard_with_expand(
         &mut self,
         usage: &GuardUsage,
@@ -1760,10 +1774,10 @@ impl FirstHop {
 
 // This is somewhat redundant with the implementations in crate::guard::Guard.
 impl tor_linkspec::HasAddrs for FirstHop {
-    fn addrs(&self) -> &[SocketAddr] {
+    fn addrs(&self) -> impl Iterator<Item = SocketAddr> {
         match &self.inner {
-            FirstHopInner::Chan(ct) => ct.addrs(),
-            FirstHopInner::Circ(ct) => ct.addrs(),
+            FirstHopInner::Chan(ct) => Either::Left(ct.addrs()),
+            FirstHopInner::Circ(ct) => Either::Right(ct.addrs()),
         }
     }
 }
@@ -1954,7 +1968,7 @@ mod test {
     #![allow(clippy::print_stdout)]
     #![allow(clippy::single_char_pattern)]
     #![allow(clippy::unwrap_used)]
-    #![allow(clippy::unchecked_duration_subtraction)]
+    #![allow(clippy::unchecked_time_subtraction)]
     #![allow(clippy::useless_vec)]
     #![allow(clippy::needless_pass_by_value)]
     //! <!-- @@ end test lint list maintained by maint/add_warning @@ -->
@@ -2095,7 +2109,7 @@ mod test {
             guardmgr.install_test_netdir(&netdir);
             let (guard, _mon, _usable) = guardmgr.select_guard(u).unwrap();
             // Make sure that the filter worked.
-            let addr = guard.addrs()[0];
+            let addr = guard.addrs().next().unwrap();
             assert_eq!(addr, "2.0.0.3:9001".parse().unwrap());
         });
     }
