@@ -530,17 +530,17 @@ mod test {
     #![allow(clippy::print_stdout)]
     #![allow(clippy::single_char_pattern)]
     #![allow(clippy::unwrap_used)]
-    #![allow(clippy::unchecked_duration_subtraction)]
+    #![allow(clippy::unchecked_time_subtraction)]
     #![allow(clippy::useless_vec)]
     #![allow(clippy::needless_pass_by_value)]
     //! <!-- @@ end test lint list maintained by maint/add_warning @@ -->
     use super::*;
-    use crate::test::create_storage_handles;
     use crate::FatalError;
+    use crate::test::create_storage_handles;
     use futures::{pin_mut, poll};
     use std::task::Poll::{self, *};
     use test_temp_dir::test_temp_dir;
-    use tor_rtcompat::BlockOn as _;
+    use tor_rtcompat::ToplevelBlockOn as _;
 
     fn test_intro_point() -> Ipt {
         use tor_netdoc::doc::hsdesc::test_data;
