@@ -14,7 +14,7 @@ pub use std::str::FromStr;
 pub use std::sync::Arc;
 pub use std::time::{Duration, SystemTime};
 
-pub use derive_deftly::{Deftly, define_derive_deftly};
+pub use derive_deftly::{Deftly, define_derive_deftly, define_derive_deftly_module};
 pub use digest::Digest;
 pub use educe::Educe;
 pub use itertools::Itertools;
@@ -33,10 +33,7 @@ pub use super::{
     keyword::KeywordRef,
     lex::{ArgumentStream, ItemStream, UnparsedItem, WS},
     lines::{Lines, StrExt as _},
-    multiplicity::{
-        ArgumentSetMethods, ArgumentSetSelector, ItemSetMethods, ItemSetSelector, ObjectSetMethods,
-        ObjectSetSelector,
-    },
+    multiplicity::{ArgumentSetMethods, ItemSetMethods, MultiplicitySelector, ObjectSetMethods},
     signatures::{
         SignatureHashInputs, SignatureItemParseable, SignedDocumentBody, sig_hash_methods,
     },
@@ -46,6 +43,7 @@ pub use super::{
         NetdocSigned,
     },
 };
+pub use crate::types::Unknown;
 pub use crate::{NormalItemArgument, netdoc_ordering_check, stop_at};
 
 pub use ArgumentError as AE;
