@@ -24,6 +24,7 @@ pub(super) mod syncview;
 
 use crate::circuit::UniqId;
 use crate::circuit::celltypes::ClientCircChanMsg;
+use crate::circuit::circhop::SendRelayCell;
 use crate::client::circuit::padding::{PaddingController, PaddingEvent, PaddingEventStream};
 use crate::client::circuit::{CircuitRxReceiver, TimeoutEstimator};
 #[cfg(feature = "hs-service")]
@@ -32,11 +33,11 @@ use crate::client::{HopLocation, TargetHop};
 use crate::crypto::cell::HopNum;
 use crate::crypto::handshake::ntor_v3::NtorV3PublicKey;
 use crate::memquota::{CircuitAccount, StreamAccount};
-use crate::stream::StreamMpscSender;
 use crate::stream::cmdcheck::AnyCmdChecker;
 use crate::stream::flow_ctrl::state::StreamRateLimit;
 use crate::stream::flow_ctrl::xon_xoff::reader::DrainRateRequest;
 use crate::stream::queue::StreamQueueReceiver;
+use crate::stream::{CloseStreamBehavior, StreamMpscSender};
 use crate::streammap;
 use crate::tunnel::{TunnelId, TunnelScopedCircId};
 use crate::util::err::ReactorError;
@@ -51,9 +52,9 @@ use std::cmp::Ordering;
 use std::collections::BinaryHeap;
 use std::mem::size_of;
 use tor_cell::relaycell::flow_ctrl::XonKbpsEwma;
-use tor_cell::relaycell::msg::{AnyRelayMsg, End, Sendme};
+use tor_cell::relaycell::msg::{AnyRelayMsg, Sendme};
 use tor_cell::relaycell::{AnyRelayMsgOuter, RelayCellFormat, StreamId, UnparsedRelayMsg};
-use tor_error::{Bug, bad_api_usage, debug_report, internal, into_bad_api_usage, warn_report};
+use tor_error::{Bug, bad_api_usage, debug_report, internal, into_bad_api_usage};
 use tor_rtcompat::{DynTimeProvider, SleepProvider};
 
 use cfg_if::cfg_if;
@@ -77,7 +78,7 @@ use tor_cell::chancell::CircId;
 use tor_llcrypto::pk;
 use tor_memquota::derive_deftly_template_HasMemoryCost;
 use tor_memquota::mq_queue::{self, MpscSpec};
-use tracing::{debug, info, trace, warn};
+use tracing::{debug, info, instrument, trace, warn};
 
 use super::circuit::{MutableState, TunnelMutableState};
 
@@ -130,27 +131,6 @@ pub(crate) enum CircuitHandshake {
     },
 }
 
-/// A behavior to perform when closing a stream.
-///
-/// We don't use `Option<End>`` here, since the behavior of `SendNothing` is so surprising
-/// that we shouldn't let it pass unremarked.
-#[derive(Clone, Debug)]
-pub(crate) enum CloseStreamBehavior {
-    /// Send nothing at all, so that the other side will not realize we have
-    /// closed the stream.
-    ///
-    /// We should only do this for incoming onion service streams when we
-    /// want to black-hole the client's requests.
-    SendNothing,
-    /// Send an End cell, if we haven't already sent one.
-    SendEnd(End),
-}
-impl Default for CloseStreamBehavior {
-    fn default() -> Self {
-        Self::SendEnd(End::new_misc())
-    }
-}
-
 // TODO: the RunOnceCmd/RunOnceCmdInner/CircuitCmd/CircuitAction enum
 // proliferation is a bit bothersome, but unavoidable with the current design.
 //
@@ -343,7 +323,11 @@ impl RunOnceCmdInner {
             CircuitCmd::Conflux(ConfluxCmd::RemoveLeg(reason)) => Self::RemoveLeg { leg, reason },
             #[cfg(feature = "conflux")]
             CircuitCmd::Conflux(ConfluxCmd::HandshakeComplete { hop, early, cell }) => {
-                let cell = SendRelayCell { hop, early, cell };
+                let cell = SendRelayCell {
+                    hop: Some(hop),
+                    early,
+                    cell,
+                };
                 Self::ConfluxHandshakeComplete { leg, cell }
             }
             #[cfg(feature = "conflux")]
@@ -353,20 +337,6 @@ impl RunOnceCmdInner {
     }
 }
 
-/// Cmd for sending a relay cell.
-///
-/// The contents of this struct are passed to `send_relay_cell`
-#[derive(educe::Educe)]
-#[educe(Debug)]
-pub(crate) struct SendRelayCell {
-    /// The hop number.
-    pub(crate) hop: HopNum,
-    /// Whether to use a RELAY_EARLY cell.
-    pub(crate) early: bool,
-    /// The cell to send.
-    pub(crate) cell: AnyRelayMsgOuter,
-}
-
 /// A command to execute at the end of [`Reactor::run_once`].
 #[derive(From, Debug)]
 #[allow(clippy::large_enum_variant)] // TODO #2003: should we resolve this?
@@ -789,6 +759,7 @@ impl Reactor {
     ///
     /// Once this method returns, the circuit is dead and cannot be
     /// used again.
+    #[instrument(level = "trace", skip_all)]
     pub async fn run(mut self) -> Result<()> {
         trace!(tunnel_id = %self.tunnel_id, "Running tunnel reactor");
         let result: Result<()> = loop {
@@ -812,6 +783,7 @@ impl Reactor {
 
     /// Helper for run: doesn't mark the circuit closed on finish.  Only
     /// processes one cell or control message.
+    #[instrument(level = "trace", skip_all)]
     async fn run_once(&mut self) -> StdResult<(), ReactorError> {
         // If all the circuits are closed, shut down the reactor
         if self.circuits.is_empty() {
@@ -932,6 +904,7 @@ impl Reactor {
 
     /// Try to process the previously-out-of-order messages we might have buffered.
     #[cfg(feature = "conflux")]
+    #[instrument(level = "trace", skip_all)]
     async fn try_dequeue_ooo_msgs(&mut self) -> StdResult<(), ReactorError> {
         // Check if we're ready to dequeue any of the previously out-of-order cells.
         while let Some(entry) = self.ooo_msgs.peek() {
@@ -970,6 +943,7 @@ impl Reactor {
     }
 
     /// Handle a [`RunOnceCmd`].
+    #[instrument(level = "trace", skip_all)]
     async fn handle_run_once_cmd(&mut self, cmd: RunOnceCmd) -> StdResult<(), ReactorError> {
         match cmd {
             RunOnceCmd::Single(cmd) => return self.handle_single_run_once_cmd(cmd).await,
@@ -989,6 +963,7 @@ impl Reactor {
     }
 
     /// Handle a [`RunOnceCmd`].
+    #[instrument(level = "trace", skip_all)]
     async fn handle_single_run_once_cmd(
         &mut self,
         cmd: RunOnceCmdInner,
@@ -1039,7 +1014,7 @@ impl Reactor {
                             .circuits
                             .leg_mut(leg)
                             .ok_or_else(|| internal!("leg disappeared?!"))?;
-                        let cell_hop = cell.hop;
+                        let cell_hop = cell.hop.expect("missing hop in client SendRelayCell?!");
                         let relay_format = circ
                             .hop_mut(cell_hop)
                             // TODO: Is this the right error type here? Or should there be a "HopDisappeared"?
@@ -1172,7 +1147,7 @@ impl Reactor {
 
                 let cell = AnyRelayMsgOuter::new(Some(stream_id), msg.into());
                 let cell = SendRelayCell {
-                    hop: hop_num,
+                    hop: Some(hop_num),
                     early: false,
                     cell,
                 };
@@ -1288,6 +1263,7 @@ impl Reactor {
     /// Wait for a [`CtrlMsg::Create`] to come along to set up the circuit.
     ///
     /// Returns an error if an unexpected `CtrlMsg` is received.
+    #[instrument(level = "trace", skip_all)]
     async fn wait_for_create(&mut self) -> StdResult<(), ReactorError> {
         let msg = select_biased! {
             res = self.command.next() => {
@@ -1343,6 +1319,7 @@ impl Reactor {
     /// the `ConfluxHandshakeContext` is consumed, and the results we have collected
     /// are sent to the handshake initiator.
     #[cfg(feature = "conflux")]
+    #[instrument(level = "trace", skip_all)]
     fn note_conflux_handshake_result(
         &mut self,
         res: StdResult<(), ConfluxHandshakeError>,
@@ -1402,7 +1379,7 @@ impl Reactor {
                     "MsgHandler doesn't have a precise HopLocation"
                 ))?;
                 Ok::<_, crate::Error>(SendRelayCell {
-                    hop,
+                    hop: Some(hop),
                     early: false,
                     cell: msg,
                 })
@@ -1487,6 +1464,7 @@ impl Reactor {
     ///
     /// Returns [`NoJoinPointError`] if trying to resolve `HopLocation::JoinPoint`
     /// but it does not have a join point.
+    #[instrument(level = "trace", skip_all)]
     fn resolve_hop_location(
         &self,
         hop: HopLocation,
@@ -1550,6 +1528,7 @@ impl Reactor {
     ///
     /// NOTE: this blocks the reactor main loop until all the cells are sent.
     #[cfg(feature = "conflux")]
+    #[instrument(level = "trace", skip_all)]
     async fn handle_link_circuits(
         &mut self,
         circuits: Vec<Circuit>,
