@@ -323,6 +323,11 @@ impl StreamMap {
         self.open_streams.len()
     }
 
+    /// Return a [`TunnelActivity`](crate::util::tunnel_activity::TunnelActivity) for this hop.
+    pub(super) fn tunnel_activity(&self) -> crate::util::tunnel_activity::TunnelActivity {
+        self.open_streams.tunnel_activity()
+    }
+
     /// Return the next available priority.
     fn take_next_priority(&mut self) -> Priority {
         let rv = self.next_priority;
@@ -584,7 +589,7 @@ mod test {
     #![allow(clippy::print_stdout)]
     #![allow(clippy::single_char_pattern)]
     #![allow(clippy::unwrap_used)]
-    #![allow(clippy::unchecked_duration_subtraction)]
+    #![allow(clippy::unchecked_time_subtraction)]
     #![allow(clippy::useless_vec)]
     #![allow(clippy::needless_pass_by_value)]
     //! <!-- @@ end test lint list maintained by maint/add_warning @@ -->
